/**
 * @file
 * Parse inline JSON and initialize the breakpointSettings global object.
 */

(function () {

  'use strict';

  var settingsElement = document.querySelector(
    'script[type="application/json"][data-theme-breakpoints-js="theme-breakpoints-js"]'
  );

  /**
   * Variable generated by Breakpoint settings.
   *
   * @global
   *
   * @type {object}
   */
  window.themeBreakpoints = {};

  if (settingsElement !== null) {
    window.themeBreakpoints = {
      Breakpoints: JSON.parse(settingsElement.textContent),
      getCurrentBreakpoint: function () {
        var breakpoints = window.themeBreakpoints.Breakpoints;
        if (!Array.isArray(breakpoints) || breakpoints.length === 0) {
          return false;
        }
        var current = breakpoints[0];
        for (var i = 1; i < breakpoints.length; i++) {
          var mq = window.matchMedia(breakpoints[i].mediaQuery);
          if (mq.matches) {
            current = breakpoints[i];
          }
        }
        return current;
      }
    };
  }
})();
